aboutsummaryrefslogtreecommitdiffstats
path: root/atuin.nix
diff options
context:
space:
mode:
Diffstat (limited to 'atuin.nix')
-rw-r--r--atuin.nix3
1 files changed, 2 insertions, 1 deletions
diff --git a/atuin.nix b/atuin.nix
index 795e927d..fa6d229d 100644
--- a/atuin.nix
+++ b/atuin.nix
@@ -37,7 +37,8 @@ rustPlatform.buildRustPackage {
# Additional flags passed to the cargo test binary, see `cargo test -- --help`
checkFlags = [
- # Registration tests require a postgres server
+ # Sync tests require a postgres server
+ "--skip=sync"
"--skip=registration"
];